@@ -29,13 +29,13 @@ try:
     import features.news.news
     import features.tell_me_about.tell_me_about
 except Exception as e:
-    from .features.weather import weather as wea
-    from .features.website_open import website_open
-    from .features.send_mail import send_mail
-    from .features.date_time import date_time
-    from .features.launch_app import launch_app
-    from .features.news import news
-    from .features.tell_me_about import tell_me_about
+    from JarvisAI.features.weather import weather as wea
+    from JarvisAI.features.website_open import website_open
+    from JarvisAI.features.send_mail import send_mail
+    from JarvisAI.features.date_time import date_time
+    from JarvisAI.features.launch_app import launch_app
+    from JarvisAI.features.news import news
+    from JarvisAI.features.tell_me_about import tell_me_about
 
 
 class JarvisAssistant:
